@@ -25,14 +25,13 @@ class DataRipper;
 class TOCReader;
 
 
-class AppChooser
- {
-   public:
-     static AudioRipper *getAudioRipper(void);
-     static DataRipper *getDataRipper(void);
-     static TOCReader *getTOCReader(void);
-     static TOCReader *readTOC(void);
- };
+class AppChooser {
+ public:
+  static AudioRipper *getAudioRipper(bool onTheFly=false);
+  static DataRipper *getDataRipper(void);
+  static TOCReader *getTOCReader(void);
+  static TOCReader *readTOC(bool readBurner=false);
+};
 
 
 #endif
