@@ -18,26 +18,25 @@
 
 */
 
-class AudioRipper : public ProcessInterface
- {
+class AudioRipper : public ProcessInterface {
   Q_OBJECT
 
-  public:
-    virtual bool ripAudio(int track,const char *filename);
-
-  protected:
-    virtual bool doRip(int track,const char *filename);
-    virtual int  processExited(void);
-
-    void startTrack(long int size);
-    void setPosition(long int pos);
-
-    int ripflag;
-    long int trackSize;
- };
-
+    public:
+  virtual bool ripAudio(int track,const char *filename);
 
+ protected:
+  virtual bool doRip(int track,const char *filename);
+  virtual int  processExited(void);
+  virtual int  processCleanup(int rval); 
+  
+  void startTrack(long int size);
+  void setPosition(long int pos);
 
+  int ripflag;
+  long int trackSize;
+ private:
+  char imageFilename[1024];
 
+};
 
 #endif
