@@ -12,17 +12,15 @@
 #include "AudioRipper.h"
 
 
-class CDParanoia : public AudioRipper
- {
+class CDParanoia : public AudioRipper {
   Q_OBJECT
+    protected:
+  virtual bool doRip(int track,const char *filename);
+  virtual bool processStderrLine(char *linebuffer);
 
-  protected:
-    virtual bool doRip(int track,const char *filename);
-    virtual bool processStderrLine(char *linebuffer);
-
-  private:
-    int paranoiafrom,paranoiato;
- };
+ private:
+  int paranoiafrom,paranoiato;
+};
 
 
 #endif
