@@ -13,24 +13,24 @@
 
 #include "ProcessInterface.h"
 
-class CDRWBlank : public ProcessInterface
- {
+class CDRWBlank : public ProcessInterface {
   Q_OBJECT;
-  public:
+ public:
 
-    enum BlankMode {Blank_All,Blank_Fast,Blank_Track,Blank_Unreserve,
-                    Blank_Tail,Blank_Unclose,Blank_Session};
-    int  blankMedia(BlankMode bmode=Blank_All);
+  enum BlankMode {Blank_All,Blank_Fast,Blank_Track,Blank_Unreserve,
+		  Blank_Tail,Blank_Unclose,Blank_Session};
+  int  blankMedia(BlankMode bmode=Blank_All);
 
   protected :
 
     virtual bool processStderrLine(char *buffer);
-    virtual bool processStdoutLine(char *buffer);
-    virtual int processExited(void);
-
-  private:
-    int burnstate;
- };
+  virtual bool processStdoutLine(char *buffer);
+  virtual int processExited(void);
+  virtual int  processCleanup(int rval);
+  
+ private:
+  int burnstate;
+};
 
 #endif
 
