@@ -1,6 +1,6 @@
 // KreateCD - CD recording software for the K desktop environment
 //
-// 1999-2000 by Alexander Feigl <Alexander.Feigl@gmx.de>
+// 1999-2001 by Alexander Feigl <Alexander.Feigl@gmx.de>
 //
 // This file is subject to the terms and conditions of the GNU General      
 // Public License.  See the file COPYING in the main directory of the       
@@ -9,9 +9,16 @@
 #ifndef CDTRACK_INCLUDED
 #define CDTRACK_INCLUDED
 
-class AudioFile;
+class AudioFileInfo;
 class ISOImage;
 class KConfig;
+class ProgressDialog;
+class AudioRipper;
+class DataRipper;
+class QObject;
+class PipeCopy;
+class AudioBuildImage;
+class AudioConversion;
 
 /**
     @short CDTrack - internal handling of a CD track
@@ -19,15 +26,17 @@ class KConfig;
 
     The CDTrack class is the internal storage class of KreateCD that handles a single track.
     It stores all neccessary information which is needed for a single track of a project.
-    It can contain pointers to additional data classes (e.g. ISOImage, AudioFile), it provides
+    It can contain pointers to additional data classes (e.g. ISOImage, AudioFileInfo), it provides
     methods to update the track, create image files etc.
 
 */
 
+
 class CDTrack
  {
   public:
 
+
   /**
       <pre>
       Track type description enums
@@ -42,6 +51,8 @@ class CDTrack
   */
     enum TrackType   {Track_Audio,Track_AudioPreEmph,Track_DataMode1,Track_DataMode2,Track_XA1,Track_XA2,Track_CDI};
 
+
+
   /**
       <pre>
       Track source enums
@@ -71,6 +82,26 @@ class CDTrack
   */
     CDTrack(void);
 
+  /**
+    This constructor provides an audio track from an AudioFileInfo structure.
+
+    @param AudioFileInfo to use
+  */
+
+    CDTrack(AudioFileInfo *afi);
+
+
+  /**
+    This constructor provides a "cloned" CDTrack object from another CDTrack. 
+    All settings are cloned but temporary file information is stripped. This is a
+    DEEP copy where pointers are not copied but subobjects are duplicated.
+
+    @param object to clone
+  */
+
+    CDTrack(const CDTrack &object);
+ 
+
   /**
     Constucts a CDTrack object from a KConfig entry. (used to load tracks from a project file).
     This contructor restores the information which is stored in a single KConfig group
@@ -123,6 +154,14 @@ class CDTrack
   */
     bool              getUseImage(void);
 
+  /**
+    This method returns a boolean whether this track needs two drives in 
+    on the fly mode. 
+
+    @return track needs two drives
+  */
+    bool              needDualDrive(void);
+
   /**
     This method copies the description of the track to a supplied character array
 
@@ -134,8 +173,9 @@ class CDTrack
     This method fills a string with the HMSB representation of the track length
 
     @param string which will be filled with track length (in time)
+    @param megabytes should be displayed too
   */
-    void              getTrackDurationHMSB(char *duration);
+    void              getTrackDurationHMSB(char *duration,bool megabytes=false);
 
   /**
     This method fills a string with the type of a track ( in words )
@@ -152,12 +192,12 @@ class CDTrack
     bool               isAudio(void);
 
   /**
-    This method returns a pointer to the associated AudioFile object for this track.
+    This method returns a pointer to the associated AudioFileInfo object for this track.
     This is only possible for audio tracks of course.
 
     @return pointer to AudioFile object or 0 if none available
   */
-    class AudioFile  *getAudioFile(void);
+    class AudioFileInfo  *getAudioFile(void);
 
   /**
     This method returns a pointer to the associated ISOImage object for this track.
@@ -184,6 +224,26 @@ class CDTrack
   */
     bool               getBurnFile(char *burnfile);
 
+  /** 
+    This method fills a char array with the filename of the named pipe which is used to
+    burn the CD-R in on the fly mode. 
+    
+    @return image file is available or not
+  */
+    bool               getOnTheFlyFile(char *burnfile);
+
+  /** 
+    This method checks if a track is setup for on the fly burning
+    
+    @return track set up on the fly burning 
+  */
+    bool               checkOnTheFly(void);
+
+  /** 
+    This method does a clean up of all on the fly stuff
+  */
+    void               cleanupOnTheFly(void);
+
   /**
     Static method to obtain a string for a certain track type. A supplied char array is
     filled with the track type name.
@@ -199,8 +259,11 @@ class CDTrack
 
     @param durationstr char array which will be filled with the HMSB representation
     @param track length (in frames/blocks) which should be encoded
+    @param isaudio - track is an audio track
+    @param megabytes - megabytes should be displayed too
   */
-    static void           getDurationHMSB(char *durationstr,long int duration);
+    static void           getDurationHMSB(char *durationstr,long int duration,
+                                          bool isaudio,bool megabytes=false);
 
   /**
     This method sets the track description of the CD track
@@ -267,6 +330,18 @@ class CDTrack
    */
     void clearImage(void);
 
+   /**
+    This function saves the current image forever. KreateCD drops the image file
+    and won't use or delete it any more 
+   */
+    void saveImage(void);   
+
+   /**
+    This is only a temporary functin, till I get saveImage, Validate, .... working the way I need it for
+    the konqueror RMB-Menu extension
+   */
+    bool  exportISO(class QString filename);
+
    /**
     This method will ensure that the information in the CD track object is consistent.
     It will update track length from real file sized and selections - it will change
@@ -279,9 +354,28 @@ class CDTrack
     This method will ensure that a valid and up to date image file is available for the
     CD track - ready to burn. It will recreate it if neccessary.
 
+    @param passed ProgressDialog if no own dialog should be used
     @return image file is available
    */
-    bool  validateTrack(void);
+    bool  validateTrack(ProgressDialog *xprog=0,const char *targetfilename=0);
+
+   /**
+    This method prepares a track for being written in on the fly mode. It might set up the necessary
+    processes to do this.
+
+    @return preparation successful
+   */
+    bool  prepareOnTheFly(PipeCopy *pipecopy);
+
+
+   /**
+    This method starts everything for a track being written in on the fly mode. It might set up the necessary
+    processes to do this.
+
+    @return preparation successful
+   */
+    bool  startOnTheFly(QObject *trigger=0);
+
 
    /**
     This method returs whether a CD track needs an image or not.
@@ -290,6 +384,31 @@ class CDTrack
     */
     bool  needImage(void);
 
+   /**
+    This method returs whether a CD track needs a temporary file or not
+
+    @return needs a temporary file
+    */
+    bool  needFile(void);
+
+   /**
+    This method forces the track size when precalculating ISO 9660 size
+
+    @param size size of  track in bytes
+   */
+
+   void setTrackSize(long int size);
+
+   /**
+     This method creates an unique file name for a track image. It fills a supplied
+     character array. You have to provide the duration/track length for this process
+
+     @param fn char array which will be filled with file name
+     @param cdrimg image is intended to be a final CD-R image, not a ripping image
+     @param duration track length for the image file (used as magic)
+   */
+    static void createName(char *fn,bool cdrimg,long int duration,bool wav=false);
+
   protected:
 
    /**
@@ -303,15 +422,11 @@ class CDTrack
 
 
   private:
-   /**
-     This method creates an unique file name for a track image. It fills a supplied
-     character array. You have to provide the duration/track length for this process
 
-     @param fn char array which will be filled with file name
-     @param cdrimg image is intended to be a final CD-R image, not a ripping image
-     @param duration track length for the image file (used as magic)
+   /**
+     This is an internal common constructor method
    */
-    void createName(char *fn,bool cdrimg,long int duration);
+    void initObject(void);
 
 
    /**
@@ -382,14 +497,55 @@ class CDTrack
     unsigned long TrackLBA;                       // LBA of Source track
 
    /**
-    internal pointer to AudioFile
+    internal pointer to AudioFileInfo
    */
-    AudioFile      *ThisAudio;
+    AudioFileInfo      *ThisAudio;
 
    /**
     internal pointer to ISOImage
    */
     ISOImage       *ThisISO;
+
+   /**
+    internal pointer to the AudioRipper for on the fly
+   */
+    AudioRipper    *onTheFlyRipper;
+
+   /**
+    internal pointer to the DataRipper for on the fly
+   */
+    DataRipper    *onTheFlyDRipper;
+
+   /**
+    internal pointer to the AudioBuildImage for on the fly
+   */
+    AudioBuildImage *onTheFlyABuildImage;
+
+   /**
+    internal pointer to the AudioConverter for on the fly
+   */
+    AudioConversion *onTheFlyAudioConverter;
+
+   /**
+    target pipe for on the fly writing
+   */
+    char            onTheFlyTarget[512];
+    
+   /**
+    pipe where the CD ripper is feeding data
+   */
+    char            onTheFlyRipPipe[512];
+
+   /**
+    pipe where the audio converter feeding data
+   */
+    char            onTheFlyAudioPipe[512];
+
+   /**
+    pipe where the audio decoder feeding data
+   */
+    char            onTheFlyDecoderPipe[512];
+    
  };
 
 
