@@ -15,29 +15,27 @@
 #include <qlayout.h>
 #include <qbuttongroup.h>
 
-class ChooseDialog : public QDialog
- {
-   Q_OBJECT
+class ChooseDialog : public QDialog {
+  Q_OBJECT
+    public:
+  ChooseDialog(const char *caption=0,const char *headertext=0, QWidget *parent=0, const char *name=0);
+  ~ChooseDialog(void);
 
-   public:
-      ChooseDialog(const char *caption=0,const char *headertext=0, QWidget *parent=0, const char *name=0);
-      ~ChooseDialog(void);
-
-     void addButton(const char *buttontext);
+  void addButton(const char *buttontext);
 
 
-   protected:
-     QButtonGroup *buttonGroup;
-     QLabel *headingText;
-     QVBoxLayout *buttonLayout;
+ protected:
+  QButtonGroup *buttonGroup;
+  QLabel *headingText;
+  QVBoxLayout *buttonLayout;
 
-     int selectedButton;
-     int buttonHeight;
-     bool doCheck;
+  int selectedButton;
+  int buttonHeight;
+  bool doCheck;
 
-   protected slots:
-     void newSelected(int selection);
-     void okButton(void);
- };
+  protected slots:
+    void newSelected(int selection);
+  void okButton(void);
+};
 
 #endif
