@@ -19,24 +19,27 @@
 
 */
 
-class DataRipper : public ProcessInterface
- {
+class DataRipper : public ProcessInterface {
   Q_OBJECT
+    public:
+  DataRipper(void);
+  DataRipper(int (*fx)(int argc,char **argv));
+  virtual bool readDataTrack(int track,char *filename,long int lba_start,long int size_hint);
 
-  public:
-    DataRipper(void);
-    DataRipper(int (*fx)(int argc,char **argv));
-    virtual bool readDataTrack(int track,char *filename,long int lba_start,long int size_hint);
+ protected:
+  virtual int  processCleanup(int rval);
+  virtual int processExited(void);
+  virtual bool ripDataTrack(char *filename,long int lba_start,long int size_hint);
 
-  protected:
-    virtual int processExited(void);
-    virtual bool ripDataTrack(char *filename,long int lba_start,long int size_hint);
+  void startTrack(long int size);
+  void setPosition(long int pos);
 
-    void startTrack(long int size);
-    void setPosition(long int pos);
+  int       ripflag;
 
-    int       ripflag;
- };
+ private:
+  char imageFilename[1024];
+};
 
 
 #endif
+
