@@ -6,33 +6,36 @@
 // Public License.  See the file COPYING in the main directory of the
 // KreateCD distribution for more details.
 
+#ifndef FORK_INCLUDED
+#define FORK_INCLUDED
+
 #include <qobject.h>
 #include <kprocess.h>
 
-class AudioFileOp;
+class ProcessInterface;
 
-class Fork : public KProcess
- {
+class Fork : public KProcess {
   Q_OBJECT;
 
-  public:
+ public:
   Fork(int (*fx)(int argc,char **argv));
-  Fork(int (*fx)(AudioFileOp *afi,const char *fn),AudioFileOp *afil,const char *fnx);
+  Fork(int (*fx)(ProcessInterface *afi,const char *fn),ProcessInterface *afil,
+       const char *fnx);
 
   bool start(RunMode, Communication);
   
   bool writeStdIn(char *buffer,int bufflen);
 
-  private:
+ private:
   int (*function)(int argc,char **argv);
 
-  int (*function_af1)(AudioFileOp *afi,const char *fn);
+  int (*function_af1)(ProcessInterface *afi,const char *fn);
 
 
   int fmode;
-  AudioFileOp *AFile;
-
+  ProcessInterface *AFile;
 
   char strarg[1024];
+};
 
- };
+#endif
