@@ -8,55 +8,53 @@
 
 #include "LineDialog.h"
 
-#if QT_VERSION >= 200
 #include <klineedit.h>
-#else
-#include <klined.h>
-#endif
 
 #include <qlayout.h>
 #include <qwindowdefs.h>
 #include <qstring.h>
+#include <klocale.h>
 
+#include "LineDialog.moc"
 
-LineDialog::LineDialog( QWidget *parent, const char *name,const char *startstring)
-           :QDialog(parent,name,TRUE,WStyle_Customize|WStyle_NoBorder|WStyle_Tool)
- {
+LineDialog::LineDialog( QWidget *parent, const char *name,
+			const char *startstring)
+  :KDialogBase( parent,name, true, 
+		i18n("Enter dirname"), Ok|Cancel, Ok, true) {
+
+  /*
   QVBoxLayout *qlay;
 
-  qlay=new QVBoxLayout(this);
+  qlay=new QVBoxLayout(this);*/
 
-#if QT_VERSION >= 200
   EditWidget=new KLineEdit(this,0);
-#else
-  EditWidget=new KLined(this,0);
-#endif
   EditWidget->setText(startstring);
-   {
+  {
     QSize qsiz;
     qsiz=EditWidget->sizeHint();
     EditWidget->setFixedHeight(qsiz.height());
 
-   }
-  qlay->addWidget(EditWidget);
+  }
+  //  qlay->addWidget(EditWidget);
   connect(EditWidget,SIGNAL(returnPressed()),
           this,SLOT(leaveDialog()));
+
   EditWidget->setFocus();
+  setMainWidget(EditWidget);
+  //  qlay->activate();
+}
 
-  qlay->activate();
- }
-
-LineDialog::~LineDialog(void)
- {
- }
+LineDialog::~LineDialog(void) {
+}
 
 
-void LineDialog::leaveDialog(void)
- {
-  done(0);
- }
+void LineDialog::leaveDialog(void) {
+  if (EditWidget->text().isEmpty())
+    done(0);
+  else
+    done(1);
+}
 
-const char *LineDialog::getInput(void)
- {
+const char *LineDialog::getInput(void) {
   return(EditWidget->text());
- }
+}
