@@ -1,34 +1,35 @@
 // KreateCD - CD recording software for the K desktop environment
 //
 // 1999-2000 by Alexander Feigl <Alexander.Feigl@gmx.de>
-//
+//  
 // This file is subject to the terms and conditions of the GNU General      
 // Public License.  See the file COPYING in the main directory of the       
 // KreateCD distribution for more details.                                     
 
+#ifndef LINEDIALOG_INCLUDED
+#define LINEDIALOG_INCLUDED
+
 #include <qwidget.h>
-#include <qdialog.h>
+#include <kdialogbase.h>
 #include <qstring.h>
 
-class LineDialog : public QDialog
- {
+class LineDialog : public KDialogBase {
   Q_OBJECT;
 
-  public:
-    LineDialog( QWidget *parent=0, const char *name=0, const char *startstring=0);
-    ~LineDialog(void);
+ public:
+  LineDialog( QWidget *parent=0, const char *name=0, 
+	      const char *startstring=0);
+  ~LineDialog(void);
 
-    const char *getInput(void);
+  const char *getInput(void);
 
   protected slots:
     void leaveDialog(void);
 
-  private:
-#if QT_VERSION >= 200
-    class KLineEdit *EditWidget;
-#else
-    class KLined *EditWidget;
+ private:
+  class KLineEdit *EditWidget;
+};
+
+
+
 #endif
- };
-
-
