@@ -11,12 +11,12 @@
 
 #include "TOCReader.h"
 
-class TOCCdda2wav : public TOCReader
- {
-   protected:
-      virtual int invokeTOCReader(void);
-      virtual bool processStderrLine(char *buffer);
- };
+class TOCCdda2wav : public TOCReader {
+ protected:
+  virtual int invokeTOCReader(bool readBurner);
+  virtual bool processStderrLine(char *buffer);
+  virtual int  processCleanup(int rval); 
+};
 
 
 #endif
