@@ -11,13 +11,12 @@
 
 #include "TOCReader.h"
 
-class TOCCdrecord : public TOCReader
- {
-   protected:
-      virtual int invokeTOCReader(void);
-      virtual bool processStdoutLine(char *buffer);
- };
+class TOCCdrecord : public TOCReader {
+ protected:
+  virtual int invokeTOCReader(bool readBurner);
+  virtual bool processStdoutLine(char *buffer);
+  virtual int  processCleanup(int rval); 
+};
 
 
 #endif
-
