@@ -15,62 +15,47 @@
 #include <kprocess.h>
 #include <kapp.h>
 #include <kconfig.h>
-#include <klocale.h>
 
 #include <strings.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <signal.h>
 
-#include "uidcontrol.h"
-#include "pathconfig.h"
+#include "TOCReader.moc"
 
-extern KLocale *locale;
+int TOCReader::readTOC(bool readBurner) {
+  return(invokeTOCReader(readBurner));
+}
 
-int TOCReader::readTOC(void)
- {
-  return(invokeTOCReader());
- }
-
-
-
-
-long int TOCReader::getTOCLBA(int track)
- {
+long int TOCReader::getTOCLBA(int track) {
   if ( (track<1) || (track>99)) return(-1);
   if ( toc_lba[track-1]==-1) return(-1);
   return(toc_lba[track-1]);
- }
+}
     
-long int TOCReader::getTOCDuration(int track)
- {
+long int TOCReader::getTOCDuration(int track) {
   if ( (track<1) || (track>99)) return(-1);
   if ( toc_lba[track-1]==-1) return(-1);
   return(toc_durat[track-1]);
- }
+}
 
-enum CDTrack::TrackType TOCReader::getTOCType(int track)
- {
+enum CDTrack::TrackType TOCReader::getTOCType(int track) {
   if ( (track<1) || (track>99)) return(CDTrack::Track_Audio);
   if ( toc_lba[track-1]==-1) return(CDTrack::Track_Audio);
   return(toc_ttype[track-1]);
- }
+}
 
-long int TOCReader::getTOCSum(void)
- {
+long int TOCReader::getTOCSum(void) {
   return(tocsum);
- }
+}
 
-void TOCReader::closeTOC(void)
- {
+void TOCReader::closeTOC(void) {
   toctracks=0;
-  while (toc_lba[toctracks]!=-1)
-   {
+  while (toc_lba[toctracks]!=-1) {
     ++toctracks;
-   }
- }
+  }
+}
 
-int TOCReader::invokeTOCReader(void)
- {
-   return(0);
- }
+int TOCReader::invokeTOCReader(bool ) {
+  return(0);
+}
