@@ -14,31 +14,30 @@
 
 typedef enum CDTrack::TrackType TrackType;
 
-class TOCReader : public ProcessInterface
- {
+class TOCReader : public ProcessInterface {
   Q_OBJECT;
-  public:
+ public:
 
-    int  readTOC(void);
+  int  readTOC(bool readBurner=false);
 
-    long int    getTOCDuration(int track);
-    long int    getTOCLBA(int track);
-    long int    getTOCSum(void);
-    TrackType   getTOCType(int track);
+  long int    getTOCDuration(int track);
+  long int    getTOCLBA(int track);
+  long int    getTOCSum(void);
+  TrackType   getTOCType(int track);
 
-  protected:
+ protected:
  
-    virtual int invokeTOCReader(void);
+  virtual int invokeTOCReader(bool readBurner);
 
-    void clearTOC(void);
-    void closeTOC(void);
+  void clearTOC(void);
+  void closeTOC(void);
 
-    long int toc_lba[128];
-    long int toc_durat[128];
-    TrackType toc_ttype[128];
-    long int tocsum;
-    int toctracks;
- };
+  long int toc_lba[128];
+  long int toc_durat[128];
+  TrackType toc_ttype[128];
+  long int tocsum;
+  int toctracks;
+};
 
 #endif
 
