@@ -9,20 +9,18 @@
 #ifndef TOPWIDGET_INCLUDED
 #define TOPWIDGET_INCLUDED
 
-#include <ktmainwindow.h>
+#include <kmainwindow.h>
 
+class TopWidget : public KMainWindow {
+  Q_OBJECT;
 
-class TopWidget : public KTMainWindow
- {
-  Q_OBJECT
+ public:
+  TopWidget(const char *name = 0L);
+  ~TopWidget(void);
+         
+  public slots:
+    void leaveMe(void);
 
-  public:
-         TopWidget(const char *name = 0L);
-         ~TopWidget(void);
-
-  private:
-         class KMenuBar      *MWMenu;
-
- };
+};
 
 #endif
